Olcsóbbat.hu - hasonlítsd össze az árakat!
Description: Böngéssz Magyarország legjobb boltjainak több mint 1 500 000 terméke között és találd meg amit keresel legyen az elektronika, számítástechnika vagy háztartási gép. Olvasd el mások véleményét és hasonlítsd össze az árakat.

Te már mindent megvettél Karácsonyra? Ajándékkereső oldalunkon sok tippet találsz! | Már csak 13 napod maradt!

- Olcsóbbat.hu - Spórolni tudni kell!

- További kategóriák

- Elektronika

  ## Kommunikáció

  - Mobiltelefon
  - GPS készülék
  - Vezeték nélküli telefon
  - Vezetékes telefon

  ## Videó

  - Tévé
  - DVD lejátszó
  - Digitális képkeret
  - Műholdas beltéri egység

  ## Fényképezők és kamerák

  - Digitális fényképező
  - Videókamera
  - Objektív
  - Vaku

  ## Audió

  - Mp3 lejátszó
  - Házimozi
  - Fülhallgató, fejhallgató
  - Mini Hifi

  ## Videójátékok és konzolok

  - Konzol
  - Videójáték kiegészítő
  - Videójáték

  ## még több elektronika

- Számítógép

  ## Hardver

  - Tablet PC
  - Laptop
  - Netbook
  - e-Book olvasó
  - Monitor
  - Asztali számítógép
  - Scanner

  ## Perifériák

  - Nyomtató
  - Router
  - Egér
  - Webkamera
  - Hangszóró
  - Billentyűzet és egér
  - Projektor

  ## Adattárolás

  - Merevlemez
  - Memóriakártya
  - Pendrive
  - Kártyaolvasó
  - CD és DVD meghajtó

  ## Számítógépes részegység

  - Videókártya
  - Alaplap
  - Processzor
  - Memória (RAM)
  - Számítógépház
  - Videódigitalizáló kártya

  ## Számítógépes kellék

  - Laptop kellék
  - Kábel és adapter
  - Headset és mikrofon
  - Számítógéptáska
  - Asztali számítógép kellék
  - Kártyaolvasó

  ## még több számítógép

- Háztartási gépek

  ## Sütés, főzés

  - Tűzhely
  - Kávéfőző
  - Sütő
  - Mikrohullámú sütő
  - Főzőlap
  - Páraelszívó

  ## Konyhagépek

  - Hűtőgép
  - Fagyasztószekrény
  - Aszalógép
  - Fritőz
  - Konyhai mérleg
  - Borhűtő

  ## Aprítás, turmixolás

  - Robotgép
  - Turmixgép
  - Gyümölcsprés és centrifuga
  - Húsdaráló
  - Szeletelőgép

  ## Mosás, takarítás

  - Mosógép és szárító
  - Porszívó
  - Mosogatógép
  - Vasaló
  - Varrógép
  - Gőztiszító

  ## Szezonális gépek

  - Split klíma
  - Mobil klíma
  - Ventilátor
  - Párologtató
  - Párátlanító
  - Levegőtisztító

  ## még több háztartási gép

- Szépségápolás

  ## Készülékek

  - Epilátor
  - Elektromos borotva
  - Hajvágó
  - Masszirozógép
  - Hajsütővas
  - Hajszárító

  ## Hajápolás

  - Hajfesték, színező
  - Hajápoló szer
  - Sampon
  - Hajformázó
  - Hajbalzsam
  - Hajregeneráló

  ## Testápolás

  - Bőrápolószer
  - Naptej, napolaj
  - Lábápolás
  - Tusfürdő
  - Testápoló
  - Kézápolás

  ## Arcápolás

  - Kozmetikum
  - Fogápoló szer
  - Fogápoló eszköz
  - Arctisztító
  - Nappali arckrém
  - Szemkörnyékápoló

  ## Smink

  - Parfüm és kölni
  - Dezodor
  - Szempillaspirál
  - Rúzs és szájfény
  - Alapozó
  - Szemceruza

  ## még több szépségápolás

- Otthon

  ## Fürdő és hálószoba

  - Kád, zuhanykabin
  - Fürdőszobai kellék
  - Ágy és ágykellék
  - Bútor
  - Lakástextília
  - Fürdő kiegészítő

  ## Festék és kellék

  - Fal- és homlokzatfesték
  - Tisztító- és takarítószer, higiénia
  - Zománcfesték
  - Favédőszer és lazúr
  - Alapozófesték

  ## Konyha

  - Edény
  - Konyhai eszköz
  - Sütés-főzés
  - Tányér és evőeszköz
  - Kés és bárd
  - Csomagolás és tárolás

  ## Kert

  - Fűnyíró
  - Kerti tárolás
  - Kertibútor
  - Kerti sütögetés
  - Fűkasza
  - Növényzet

  ## Barkácsolás

  - Mérőműszer
  - Hosszabbító, elosztó
  - Sarokcsiszoló
  - Dekopírfűrész
  - Napelem
  - Fúrógép

  ## még több otthon

- Sport

  ## Kültéri sportok

  - Távcső
  - Sátor
  - Hűtőtáska
  - Kemping felszerelés
  - Hálózsák
  - Elemlámpa

  ## Fitness

  - Szobakerékpár
  - Futópad
  - Elliptikus tréner
  - Edzőpad
  - Vibrációs tréner
  - Kondigép

  ## Labdajátékok

  - Asztalitenisz
  - Tenisz
  - Futball
  - Kosárlabda
  - Kézilabda
  - Röplabda

  ## Kerekeken

  - Görkorcsolya
  - Roller
  - Gördeszka
  - Gyermek kerékpár
  - City kerékpár
  - Kerékpár külső gumi

  ## Vizisportok

  - Medence
  - Búvárfelszerelés
  - Úszófelszerelés
  - Felfújható csónak
  - Hajózási felszerelés

  ## még több sport

- Autó

  ## Autó elektronika

  - Autórádió
  - Autós hangszóró
  - Autós DVD lejátszó
  - Autós mélynyomó
  - Autós erősítő

  ## Autó kellékek

  - Légterelő
  - Ablaktörlő lapát
  - Autóápoló eszköz
  - Autó akkumulátor
  - Tetőcsomagtartó

  ## Kenőanyagok

  - Motorolaj
  - Váltó olaj
  - Hidraulikaolaj
  - Fékolaj
  - Motorolaj adalék

  ## Kerék, autógumi

  - Nyári gumiabroncs
  - Alufelni
  - Négyévszakos
  - Dísztárcsa

  ## Szűrők

  - Olajszűrő
  - Pollenszűrő
  - Levegőszűrő
  - Benzinszűrő

  ## még több autó

- Játék

  ## Építőjáték

  - Lego
  - Playmobil
  - Barkácsolás, építés
  - Mágneses építőjáték

  ## Társasjáték, készségfejlesztő

  - Társasjáték
  - Puzzle
  - Logikai játék
  - Elektronikus játék

  ## Figura és baba

  - Játékbaba
  - Plüssfigura
  - Akciófigura
  - Játékfigura

  ## Modell

  - Autópálya és játékautó
  - Távirányítós modell
  - Thomas, a gőzmozdony
  - Makett figura

  ## Kerti játék

  - Vizes játék
  - Lábbal hajtható járgány
  - Kerti játszóház
  - Sportjáték

  ## még több játék

- Egészség
- Karácsony
- Élményajándék (ˣ)

Mobiltelefon
Tablet PC
Laptop
Tévé
Digitális fényképező
Hűtőgép, hűtőszekrény
Mosógép és szárító
Tűzhely
Nyomtató
Kávéfőző
Porszívó
Monitor
GPS készülék
Mikrohullámú sütő
Merevlemez
e-Book olvasó
Mosogatógép
Fülhallgató, fejhallgató
Parfüm és kölni
Asztali számítógép
Főzőlap

## Ők is nálunk vannak

- már
  2863
  regisztrált webshop

## Karácsonyi ajándékkereső

Segítünk választani és olcsóbban megúszhatod.

## Kedvenceink

- ### Itt az új iPhone 6!

  #### Nézd meg mit tud!

- ### iPhone 6 Plus

  #### A méret a lényeg

- ### Sport új dimenzióban

  #### Polaroid XS20 Sportkamera

  29 989 Ft

- ### Sulihoz hasznos

  #### Kingston DataTraveler SE9 16 GB Pendrive

  2 784 Ft

- HIRDETÉS

## Népszerű kategóriák

- - Nyári gumiabroncs
  - Split klíma
  - Mobil klíma
  - Ventilátor
  - Kerti játszóház
  - Konzol
  - Mobiltelefon
  - Tablet PC
  - Laptop
  - Tévé
  - Digitális fényképező
  - e-Book olvasó
  - Kávéfőző
  - Mosógép és szárító
  - Mosogatógép
  - Tűzhely
  - Főzőlap
  - Hűtőgép, hűtőszekrény
  - Porszívó
  - Nyomtató
  - Monitor
  - GPS készülék
  - Merevlemez
  - Parfüm és kölni

## Vásárlási tippek Összes vásárlási tipp

- ### Hajlított képernyő és az egészségre figyelő okostelefon

  lg mobilnet samsung

  Az LG és a Samsung is sok újdonsággal rukkolt elő a legújabb csúcskategóriás okostelefonjaiban.

## Népszerű termékek

- ### Samsung Galaxy... #### samsung

  35 800 Ft

- ### DPS Titan 8 Wi-Fi... #### dps

  19 900 Ft

- ### LG 32LB550B #### lg

  59 990 Ft

- ### Nikon D3200 #### nikon

  92 900 Ft

- ### Asus X551CA-SX143D... #### asus

  83 900 Ft

- ### Electrolux... #### electrolux

  78 900 Ft

- ### Burberry Weekend... #### burberry

  7 590 Ft

- ### Philips Senseo... #### philips

  17 290 Ft

- ### LEGO Friends -... #### lego

  6 990 Ft

- ### Sencor SVC 530 #### sencor

  10 590 Ft

- ### Samsung CLP-365W #### samsung

  34 862 Ft

- ### Zanussi ZCG51011WA #### zanussi

  53 900 Ft

- ### Zanussi ZRB 33104... #### zanussi

  91 900 Ft

- ### Amazon Kindle... #### amazon

  41 900 Ft

- ### Timex T2N720 #### timex

  35 450 Ft

- ### Piatnik Activity My... #### piatnik

  4 250 Ft

- ### Sennheiser HD 201 #### sennheiser

  7 090 Ft

- ### NAVON N490 #### navon

  21 700 Ft

- ### Philips SA5MXX02KF #### philips

  7 999 Ft

- ### Sencor STM 3011GR #### sencor

  24 900 Ft

- Olcsóbbat közösség
- Blog
- Facebook
- iPhone app
- Android app
- Mobil nézet

- Spórolni tudni kell!
- Új termékek
- Népszerű termékek
- Gyártók
- Boltok
- Mobilnet

- Hasznos
- Vásárlási tanácsok
- Segítség
- Felhasználási feltételek
- Adatvédelem
- Impresszum

- Csatlakozz hozzánk!
- Belépés boltoknak
- Információ boltoknak
- Regisztráció boltoknak
- Webshopot szeretne?
- ÁSZF

## Hírlevél feliratkozás

Olcsóbbat.hu - © 2005-2014 Central Médiacsoport Zrt.

Elrejt Nagyít +

- ### Utoljára megtekintett (0)

  Összes törlése
  0 Utoljára megtekintett

- ### Árfigyelés (0)

  Összes törlése
  Az Árfigyelés beállítással időben értesülhetsz, ha a figyelt termék a megadott ár alá csökkent.
  Minden kiválasztott terméket 30 napig figyelünk Neked!
  Ahhoz, hogy itt is lásd beállított árfigyeléseidet regisztrálj, vagy lépj be.
  0 Árfigyelés

- Bejelentkezés | Regisztráció

- Termékkategóriák:

Összehasonlítom
Összes elem eltávolítása

### Olcsóbbat.hu eszköztára

segítségével beállíthatsz árfigyelést, összehasonlíthatsz termékeket...

| Bezár

### Olcsóbbat.hu eszköztára

segítségével beállíthatsz árfigyelést, összehasonlíthatsz termékeket...

| Kinyit